==> aiogoogle-0.0.1a2.tar.gz: aiogoogle-0.0.1a2/tests/test_globals.py <==
ALL_APIS = [('abusiveexperiencereport', 'v1'),
 ('acceleratedmobilepageurl', 'v1'),
 ('accesscontextmanager', 'v1beta'),
 ('adexchangebuyer', 'v1.4'),
 ('adexchangebuyer2', 'v2beta1'),
 ('adexperiencereport', 'v1'),
 ('admin', 'reports_v1'),
 ('adsense', 'v1.4'),
 ('adsensehost', 'v4.1'),
 ('alertcenter', 'v1beta1'),
 ('analytics', 'v3'),
 ('analyticsreporting', 'v4'),
 ('androiddeviceprovisioning', 'v1'),
 ('androidenterprise', 'v1'),
 ('androidmanagement', 'v1'),
 ('androidpublisher', 'v3'),
 ('appengine', 'v1'),
 ('appsactivity', 'v1'),
 ('appstate', 'v1'),
 ('bigquery', 'v2'),
 ('bigquerydatatransfer', 'v1'),
 ('binaryauthorization', 'v1beta1'),
 ('blogger', 'v3'),
 ('books', 'v1'),
 ('calendar', 'v3'),
 ('chat', 'v1'),
 ('civicinfo', 'v2'),
 ('classroom', 'v1'),
 ('cloudasset', 'v1beta1'),
 ('cloudbilling', 'v1'),
 ('cloudbuild', 'v1'),
 ('clouddebugger', 'v2'),
 ('clouderrorreporting', 'v1beta1'),
 ('cloudfunctions', 'v1'),
 ('cloudiot', 'v1'),
 ('cloudkms', 'v1'),
 ('cloudprofiler', 'v2'),
 ('cloudresourcemanager', 'v2'),
 ('cloudscheduler', 'v1beta1'),
 ('cloudsearch', 'v1'),
 ('cloudshell', 'v1'),
 ('cloudtasks', 'v2beta3'),
 ('cloudtrace', 'v2'),
 ('composer', 'v1'),
 ('compute', 'v1'),
 ('container', 'v1'),
 ('content', 'v2'),
 ('customsearch', 'v1'),
 ('dataflow', 'v1b3'),
 ('dataproc', 'v1'),
 ('datastore', 'v1'),
 ('deploymentmanager', 'v2'),
 ('dfareporting', 'v3.2'),
 ('dialogflow', 'v2'),
 ('digitalassetlinks', 'v1'),
 ('discovery', 'v1'),
 ('dlp', 'v2'),
 ('dns', 'v1'),
 ('doubleclickbidmanager', 'v1'),
 ('doubleclicksearch', 'v2'),
 ('drive', 'v3'),
 ('driveactivity', 'v2'),
 ('file', 'v1beta1'),
 ('firebasedynamiclinks', 'v1'),
 ('firebasehosting', 'v1beta1'),
 ('firebaserules', 'v1'),
 ('firestore', 'v1'),
 ('fitness', 'v1'),
 ('fusiontables', 'v2'),
 ('games', 'v1'),
 ('gamesConfiguration', 'v1configuration'),
 ('gamesManagement', 'v1management'),
 ('genomics', 'v1'),
 ('gmail', 'v1'),
 ('groupsmigration', 'v1'),
 ('groupssettings', 'v1'),
 ('iam', 'v1'),
 ('iamcredentials', 'v1'),
 ('iap', 'v1beta1'),
 ('identitytoolkit', 'v3'),
 ('indexing', 'v3'),
 ('jobs', 'v3'),
 ('kgsearch', 'v1'),
 ('language', 'v1'),
 ('licensing', 'v1'),
 ('logging', 'v2'),
 ('manufacturers', 'v1'),
 ('mirror', 'v1'),
 ('ml', 'v1'),
 ('monitoring', 'v3'),
 ('oauth2', 'v2'),
 ('oslogin', 'v1'),
 ('pagespeedonline', 'v5'),
 #('partners', 'v2'),
 ('people', 'v1'),
 ('playcustomapp', 'v1'),
 ('plus', 'v1'),
 ('plusDomains', 'v1'),
 ('poly', 'v1'),
 ('proximitybeacon', 'v1beta1'),
 ('pubsub', 'v1'),
 ('redis', 'v1'),
 ('replicapool', 'v1beta1'),
 ('replicapoolupdater', 'v1beta1'),
 ('reseller', 'v1'),
 ('runtimeconfig', 'v1'),
 ('safebrowsing', 'v4'),
 ('script', 'v1'),
 ('searchconsole', 'v1'),
 ('servicebroker', 'v1'),
 ('serviceconsumermanagement', 'v1'),
 ('servicecontrol', 'v1'),
 ('servicemanagement', 'v1'),
 ('servicenetworking', 'v1beta'),
 ('serviceusage', 'v1'),
 ('sheets', 'v4'),
 ('siteVerification', 'v1'),
 ('slides', 'v1'),
 ('sourcerepo', 'v1'),
 ('spanner', 'v1'),
 ('speech', 'v1'),
 ('sqladmin', 'v1beta4'),
 ('storage', 'v1'),
 ('storagetransfer', 'v1'),
 ('streetviewpublish', 'v1'),
 ('surveys', 'v2'),
 ('tagmanager', 'v2'),
 ('tasks', 'v1'),
 ('testing', 'v1'),
 ('texttospeech', 'v1'),
 ('toolresults', 'v1beta3'),
 ('tpu', 'v1'),
 ('translate', 'v2'),
 ('urlshortener', 'v1'),
 ('vault', 'v1'),
 ('videointelligence', 'v1'),
 ('vision', 'v1'),
 ('webfonts', 'v1'),
 ('webmasters', 'v3'),
 ('websecurityscanner', 'v1alpha'),
 ('youtube', 'v3'),
 ('youtubeAnalytics', 'v2'),
 ('youtubereporting', 'v1')]

==> aiogoogle-0.1.4.tar.gz: aiogoogle-0.1.4/tests/test_globals.py <==
ALL_APIS = [('abusiveexperiencereport', 'v1'),
 ('acceleratedmobilepageurl', 'v1'),
 ('accesscontextmanager', 'v1'),
 ('adexchangebuyer', 'v1.4'),
 ('adexchangebuyer2', 'v2beta1'),
 ('adexperiencereport', 'v1'),
 ('admin', 'reports_v1'),
 ('adsense', 'v1.4'),
 ('adsensehost', 'v4.1'),
 ('alertcenter', 'v1beta1'),
 ('analytics', 'v3'),
 ('analyticsreporting', 'v4'),
 ('androiddeviceprovisioning', 'v1'),
 ('androidenterprise', 'v1'),
 ('androidmanagement', 'v1'),
 ('androidpublisher', 'v3'),
 ('appengine', 'v1'),
 ('appsactivity', 'v1'),
 ('appstate', 'v1'),
 ('bigquery', 'v2'),
 ('bigquerydatatransfer', 'v1'),
 ('bigtableadmin', 'v2'),
 ('binaryauthorization', 'v1beta1'),
 ('blogger', 'v3'),
 ('books', 'v1'),
 ('calendar', 'v3'),
 ('chat', 'v1'),
 ('civicinfo', 'v2'),
 ('classroom', 'v1'),
 ('cloudasset', 'v1beta1'),
 ('cloudbilling', 'v1'),
 ('cloudbuild', 'v1'),
 ('clouddebugger', 'v2'),
 ('clouderrorreporting', 'v1beta1'),
 ('cloudfunctions', 'v1'),
 ('cloudidentity', 'v1'),
 ('cloudiot', 'v1'),
 ('cloudkms', 'v1'),
 ('cloudprivatecatalog', 'v1beta1'),
 ('cloudprivatecatalogproducer', 'v1beta1'),
 ('cloudprofiler', 'v2'),
 ('cloudresourcemanager', 'v2'),
 ('cloudscheduler', 'v1beta1'),
 ('cloudsearch', 'v1'),
 ('cloudshell', 'v1'),
 ('cloudtasks', 'v2beta3'),
 ('cloudtrace', 'v2'),
 ('composer', 'v1'),
 ('compute', 'v1'),
 ('container', 'v1'),
 ('containeranalysis', 'v1alpha1'),
 ('content', 'v2.1'),
 ('customsearch', 'v1'),
 ('dataflow', 'v1b3'),
 ('dataproc', 'v1'),
 ('datastore', 'v1'),
 ('deploymentmanager', 'v2'),
 ('dfareporting', 'v3.3'),
 ('dialogflow', 'v2'),
 ('digitalassetlinks', 'v1'),
 ('discovery', 'v1'),
 ('dlp', 'v2'),
 ('dns', 'v1'),
 ('docs', 'v1'),
 ('doubleclickbidmanager', 'v1'),
 ('doubleclicksearch', 'v2'),
 ('drive', 'v3'),
 ('driveactivity', 'v2'),
 ('file', 'v1'),
 ('firebasedynamiclinks', 'v1'),
 ('firebasehosting', 'v1beta1'),
 ('firebaserules', 'v1'),
 ('firestore', 'v1'),
 ('fitness', 'v1'),
 ('fusiontables', 'v2'),
 ('games', 'v1'),
 ('gamesConfiguration', 'v1configuration'),
 ('gamesManagement', 'v1management'),
 ('genomics', 'v1'),
 ('gmail', 'v1'),
 ('groupsmigration', 'v1'),
 ('groupssettings', 'v1'),
 ('healthcare', 'v1alpha2'),
 ('iam', 'v1'),
 ('iamcredentials', 'v1'),
 ('iap', 'v1'),
 ('identitytoolkit', 'v3'),
 ('indexing', 'v3'),
 ('jobs', 'v3'),
 ('kgsearch', 'v1'),
 ('language', 'v1'),
 ('libraryagent', 'v1'),
 ('licensing', 'v1'),
 ('logging', 'v2'),
 ('manufacturers', 'v1'),
 ('mirror', 'v1'),
 ('ml', 'v1'),
 ('monitoring', 'v3'),
 ('oauth2', 'v2'),
 ('oslogin', 'v1'),
 ('pagespeedonline', 'v5'),
 ('people', 'v1'),
 ('playcustomapp', 'v1'),
 ('plus', 'v1'),
 ('plusDomains', 'v1'),
 ('poly', 'v1'),
 ('proximitybeacon', 'v1beta1'),
 ('pubsub', 'v1'),
 ('redis', 'v1'),
 ('remotebuildexecution', 'v2'),
 ('replicapool', 'v1beta1'),
 ('reseller', 'v1'),
 ('runtimeconfig', 'v1'),
 ('safebrowsing', 'v4'),
 ('script', 'v1'),
 ('searchconsole', 'v1'),
 ('servicebroker', 'v1'),
 ('serviceconsumermanagement', 'v1'),
 ('servicecontrol', 'v1'),
 ('servicemanagement', 'v1'),
 ('servicenetworking', 'v1beta'),
 ('serviceusage', 'v1'),
 ('sheets', 'v4'),
 ('siteVerification', 'v1'),
 ('slides', 'v1'),
 ('sourcerepo', 'v1'),
 ('spanner', 'v1'),
 ('speech', 'v1'),
 ('sqladmin', 'v1beta4'),
 ('storage', 'v1'),
 ('storagetransfer', 'v1'),
 ('streetviewpublish', 'v1'),
 ('surveys', 'v2'),
 ('tagmanager', 'v2'),
 ('tasks', 'v1'),
 ('testing', 'v1'),
 ('texttospeech', 'v1'),
 ('toolresults', 'v1beta3'),
 ('tpu', 'v1'),
 ('translate', 'v2'),
 ('urlshortener', 'v1'),
 ('vault', 'v1'),
 ('videointelligence', 'v1'),
 ('vision', 'v1'),
 ('webfonts', 'v1'),
 ('webmasters', 'v3'),
 ('websecurityscanner', 'v1alpha'),
 ('youtube', 'v3'),
 ('youtubeAnalytics', 'v2'),
 ('youtubereporting', 'v1')]
